#!/bin/sh
# Copyright (c) 2020 Synology Inc. All rights reserved.

DRIVE_PKG_PATH="/var/packages/SynologyDrive/"
DRIVE_INFO_FILE=${DRIVE_PKG_PATH}"INFO"
DRIVE_DB_CONFIG_PATH=${DRIVE_PKG_PATH}"etc/db-path.conf"
DRIVE_USER_DB_RELATIVE_PATH="@synologydrive/@sync/user-db.sqlite"
VERSION_KEY="version"
OLD_DRIVE_MAJOR_VERSION=2

UPGRADE_WIZARD_TITLE="Synology Drive Server - 升级套件"
UPGRADE_WIZARD_DESC="请注意，升级到 <b>Synology Drive Server</b> 之前，Synology Drive 套件和 Cloud Station 套件（Cloud Station Drive、Backup、ShareSync 或 DS cloud）的所有应用程序都必须改为使用 Synology Drive 套件中对应的最新版本应用程序以确保兼容性。"

IsUpgradeFromDrive1or2()
{
	if [ ! -f "${DRIVE_INFO_FILE}" ]; then
		return 0
	fi

	local drive_major=$(/bin/get_key_value "${DRIVE_INFO_FILE}" "${VERSION_KEY}" | cut -d '.' -f 1)

	if [ ${drive_major} -le ${OLD_DRIVE_MAJOR_VERSION} ]; then
		return 1
	fi

	return 0
}

IsClientUpgradeNeeded()
{
	IsUpgradeFromDrive1or2
	local drive1_or_2_upgrade=$?

	if [ "${drive1_or_2_upgrade}" = "0" ]; then
		return 0
	fi

	if [ ! -f "${DRIVE_DB_CONFIG_PATH}" ]; then
		return 0
	fi

	local db_volume=$(/usr/bin/get_key_value "${DRIVE_DB_CONFIG_PATH}" "db-vol")

	if [ -z "${db_volume}" ]; then
		return 0
	fi

	local user_db_path="${db_volume}/${DRIVE_USER_DB_RELATIVE_PATH}"

	if [ -f "${user_db_path}" ]; then
		local result=$(/usr/bin/sqlite3 "${user_db_path}" "SELECT EXISTS (SELECT 1 FROM session_table as st, user_table as ut WHERE ut.id = st.uid);")

		if [ "$result" = "1" ]; then
			return 1
		fi
	fi

	return 0
}


main()
{
	local UpgradePages=""
	IsClientUpgradeNeeded
	local client_upgrade_needed=$?

	if [ "${client_upgrade_needed}" = "0" ]; then
		UpgradePages=""
	else
		read -r -d '' UpgradePages <<EOF
{
	"step_title": "$UPGRADE_WIZARD_TITLE",
	"items": [{
		"desc": "$UPGRADE_WIZARD_DESC"
	}]
}
EOF
	fi

	/bin/echo "[${UpgradePages}]" > ${SYNOPKG_TEMP_LOGFILE}

	exit 0
}

main "$@"
